@@ -4,6 +4,7 @@ import asyncio
 import typing
 from ccxt.base import errors as ccxt_errors
 import ccxt.pro as ccxt
+from contextlib import suppress
 
 # import ccxt.async_support as ccxt
 from decimal import Decimal
@@ -57,9 +58,7 @@ class ZCCXT:
         self.identifier = identifier
 
     @classmethod
-    async def create(
-        cls, api_key: str, api_secret: str, exchange: ExchangeEnum, is_demo=False, identifier=None
-    ):
+    async def create(cls, api_key: str, api_secret: str, exchange: ExchangeEnum, is_demo=False, identifier=None):
         self = cls(api_key, api_secret, exchange, is_demo, identifier)
 
         params = {
@@ -221,8 +220,14 @@ class ZCCXT:
 
                 if order_type == "open":
                     return await self.client.fetch_open_order(order_id, params={"category": market_value})
-                return await self.client.fetch_closed_order(order_id, params={"category": market_value})
-
+                elif order_type == "close":
+                    return await self.client.fetch_closed_order(order_id, params={"category": market_value})
+                else:
+                    # we want to suppress the 1st exception, but we're ok to raise an error for the 2nd call
+                    # so it gets captured one level above
+                    with suppress(ccxt_errors.OrderNotFound):
+                        return await self.client.fetch_open_order(order_id, params={"category": market_value})
+                    return await self.client.fetch_closed_order(order_id, params={"category": market_value})
             return await self.client.fetch_order(order_id)
         except ccxt_errors.OrderNotFound:
             return None
@@ -384,27 +389,25 @@ class ZCCXT:
         if reduce_only:
             params.update({"reduceOnly": reduce_only})
 
-        price = None
-        if self.exchange in [ExchangeEnum.HYPERLIQUID]:
-            # price is required for some exchanges in order to calc. slippage
-            slippage = self.client.options["defaultSlippage"]
-            orderbook = await self.get_orderbook(symbol)
-            if side == SideEnum.SELL:
-                base_price = orderbook["bids"][0][0]
-                # For sells, reduce price by slippage percentage
-                price = base_price * (1 - slippage)
-            else:
-                base_price = orderbook["asks"][0][0]
-                # For buys, increase price by slippage percentage
-                price = base_price * (1 + slippage)
+        # price is required for some exchanges in order to calc. slippage
+        slippage = self.client.options.get("defaultSlippage", 0)
+        orderbook = await self.get_orderbook(symbol)
+        if side == SideEnum.SELL:
+            base_price = orderbook["bids"][0][0]
+            # For sells, reduce price by slippage percentage
+            price = base_price * (1 - slippage)
+        else:
+            base_price = orderbook["asks"][0][0]
+            # For buys, increase price by slippage percentage
+            price = base_price * (1 + slippage)
 
-            # Convert to Decimal and round to appropriate precision
-            price = Decimal(str(price)).quantize(Decimal("0.00000001"))
+        # Convert to Decimal and round to appropriate precision
+        price = Decimal(str(price)).quantize(Decimal("0.00000001"))
 
         log.info("Creating %s order for %s with price=%s amount=%s", side, symbol, price, amount)
         try:
-            live_order = await self.client.create_limit_order(
-                symbol, side=side.value, amount=amount, price=price, params=params
+            live_order = await self.client.create_order(
+                symbol, "market", side=side.value, amount=amount, price=price, params=params
             )
         except ccxt_errors.InvalidOrder as e:
             if self.exchange == ExchangeEnum.HYPERLIQUID:
@@ -420,6 +423,7 @@ class ZCCXT:
         if not live_order.get("side"):
             live_order["side"] = side.value
         # End
+
         return live_order
 
     async def edit_order(
@@ -724,8 +728,8 @@ class ZCCXT:
                     "equity": Decimal(coin["equity"]).quantize(Decimal("0.00000001")),
                     "balance": Decimal(coin["walletBalance"]).quantize(Decimal("0.00000001")),
                     "is_collateral": coin["collateralSwitch"],
-                    "total": Decimal(str(response["total"].get(token, 0))).quantize(Decimal("0.00000001")),
-                    "free": Decimal(str(response["free"].get(token, 0))).quantize(Decimal("0.00000001")),
+                    "total": Decimal(str(response["total"].get(token, 0) or 0)).quantize(Decimal("0.00000001")),
+                    "free": Decimal(str(response["free"].get(token, 0) or 0)).quantize(Decimal("0.00000001")),
                     # "availableToWithdraw": Decimal(coin["availableToWithdraw"]),
                     # "unrealisedPnl": Decimal(coin["unrealisedPnl"]),
                     # "cumRealisedPnl": Decimal(coin["cumRealisedPnl"]),
@@ -789,8 +793,8 @@ class ZCCXT:
                     "usdValue": (Decimal(item["holding"]) * Decimal(current_price)).quantize(Decimal("0.00000001")),
                     "equity": Decimal(item["holding"]).quantize(Decimal("0.00000001")),
                     "balance": Decimal(item["availableBalance"]).quantize(Decimal("0.00000001")),
-                    "total": Decimal(str(response["total"].get(token, 0))).quantize(Decimal("0.00000001")),
-                    "free": Decimal(str(response["free"].get(token, 0))).quantize(Decimal("0.00000001")),
+                    "total": Decimal(str(response["total"].get(token, 0) or 0)).quantize(Decimal("0.00000001")),
+                    "free": Decimal(str(response["free"].get(token, 0) or 0)).quantize(Decimal("0.00000001")),
                 }
 
         elif self.exchange == ExchangeEnum.HYPERLIQUID:
@@ -836,8 +840,8 @@ class ZCCXT:
                 "equity": Decimal(response["total"][token]).quantize(Decimal("0.00000001")),
                 "balance": Decimal(response["free"][token]).quantize(Decimal("0.00000001")),
                 # we have this to make it compatible with other dicts
-                "total": Decimal(str(response["total"].get(token, 0))).quantize(Decimal("0.00000001")),
-                "free": Decimal(str(response["free"].get(token, 0))).quantize(Decimal("0.00000001")),
+                "total": Decimal(str(response["total"].get(token, 0) or 0)).quantize(Decimal("0.00000001")),
+                "free": Decimal(str(response["free"].get(token, 0) or 0)).quantize(Decimal("0.00000001")),
             }
 
             # we get other token balances from type=spot request, we don't really care much about USDC value ... but hmm, maybe we should
@@ -853,8 +857,8 @@ class ZCCXT:
                     "equity": Decimal(response_spot["total"][token]).quantize(Decimal("0.00000001")),
                     "balance": Decimal(response_spot["free"][token]).quantize(Decimal("0.00000001")),
                     # we have this to make it compatible with other dicts
-                    "total": Decimal(str(response_spot["total"].get(token, 0))).quantize(Decimal("0.00000001")),
-                    "free": Decimal(str(response_spot["free"].get(token, 0))).quantize(Decimal("0.00000001")),
+                    "total": Decimal(str(response_spot["total"].get(token, 0) or 0)).quantize(Decimal("0.00000001")),
+                    "free": Decimal(str(response_spot["free"].get(token, 0) or 0)).quantize(Decimal("0.00000001")),
                 }
 
         else:
@@ -957,5 +961,8 @@ class ZCCXT:
         except ccxt_errors.OrderNotFound:
             return
         except ccxt_errors.BadRequest as e:
-            if "Order has been terminated" not in e.args[0]:  # WOO error ...
-                raise e
+            if "order can not be found" in e.args[0].lower():  # woo error
+                return
+            elif "order has been terminated" in e.args[0].lower():  # WOO error ...
+                return
+            raise e
